@@ -175,6 +175,9 @@ Fapi_VerifyQuote_Async(
     check_not_null(quoteInfo);
     check_not_null(signature);
 
+    /* Cleanup command context. */
+    memset(&context->cmd, 0, sizeof(IFAPI_CMD_STATE));
+
     if (context->state != _FAPI_STATE_INIT) {
         return_error(TSS2_FAPI_RC_BAD_SEQUENCE, "Invalid State");
     }
