@@ -2,6 +2,10 @@
 /*
  * Copyright 2020 Fraunhofer SIT. All rights reserved.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <errno.h>
 #include <fcntl.h>
 #include <inttypes.h>
@@ -18,10 +22,12 @@
 #include "tss2_mu.h"
 #include "tcti-common.h"
 #include "tcti-spi-helper.h"
-#include "util/io.h"
+#include "util/tss2_endian.h"
 #define LOGMODULE tcti
 #include "util/log.h"
 
+#define TIMEOUT_B 2000 // The default timeout value as specified in the TCG spec
+
 static inline TSS2_RC spi_tpm_helper_delay_ms(TSS2_TCTI_SPI_HELPER_CONTEXT* ctx, int milliseconds)
 {
     // Sleep a specified amount of milliseconds
@@ -312,7 +318,7 @@ static uint32_t spi_tpm_helper_read_sts_reg(TSS2_TCTI_SPI_HELPER_CONTEXT* ctx)
 {
     uint32_t status = 0;
     spi_tpm_helper_read_reg(ctx, TCTI_SPI_HELPER_TPM_STS_REG, &status, sizeof(status));
-    return status;
+    return LE_TO_HOST_32(status);
 }
 
 static void spi_tpm_helper_write_sts_reg(TSS2_TCTI_SPI_HELPER_CONTEXT* ctx, uint32_t status)
@@ -621,7 +627,7 @@ TSS2_RC tcti_spi_helper_transmit (TSS2_TCTI_CONTEXT *tcti_ctx, size_t size, cons
 
     // Wait until ready bit is set by TPM device
     uint32_t expected_status_bits = TCTI_SPI_HELPER_TPM_STS_COMMAND_READY;
-    rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, 200);
+    rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, TIMEOUT_B);
     if (rc != TSS2_RC_SUCCESS) {
         LOG_ERROR("Failed waiting for TPM to become ready");
         return rc;
@@ -674,6 +680,10 @@ TSS2_RC Tss2_Tcti_Spi_Helper_Init (TSS2_TCTI_CONTEXT* tcti_context, size_t* size
         return TSS2_RC_SUCCESS;
     }
 
+    if (!platform_conf) {
+        return TSS2_TCTI_RC_BAD_VALUE;
+    }
+
     if (*size < sizeof (TSS2_TCTI_SPI_HELPER_CONTEXT)) {
         return TSS2_TCTI_RC_INSUFFICIENT_BUFFER;
     }
@@ -727,14 +737,23 @@ TSS2_RC Tss2_Tcti_Spi_Helper_Init (TSS2_TCTI_CONTEXT* tcti_context, size_t* size
         return TSS2_TCTI_RC_IO_ERROR;
     }
 
-    // Wait up to 200ms for TPM to become ready
+    // Wait up to TIMEOUT_B for TPM to become ready
     LOG_DEBUG("Waiting for TPM to become ready...");
     uint32_t expected_status_bits = TCTI_SPI_HELPER_TPM_STS_COMMAND_READY;
-    rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, 200);
+    rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, TIMEOUT_B);
+    if (rc == TSS2_TCTI_RC_TRY_AGAIN) {
+        /*
+         * TPM did not auto transition into ready state,
+         * write 1 to commandReady to start the transition.
+         */
+        spi_tpm_helper_write_sts_reg(ctx, TCTI_SPI_HELPER_TPM_STS_COMMAND_READY);
+        rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, TIMEOUT_B);
+    }
     if (rc != TSS2_RC_SUCCESS) {
         LOG_ERROR("Failed waiting for TPM to become ready");
         return rc;
     }
+
     LOG_DEBUG("TPM is ready");
 
     // Get rid
