@@ -1,21 +1,26 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  *******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 
 #include "tss2_esys.h"
 
 #include "esys_iutil.h"
-#include "test-esapi.h"
+#include "test-esys.h"
 #define LOGMODULE test
 #include "util/log.h"
+#include "util/aux_util.h"
 
-/** Test the ESAPI function Esys_ECC_Parameters. 
+/** Test the ESYS function Esys_ECC_Parameters.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_ECC_Parameters() (M)
  *
  * @param[in,out] esys_context The ESYS_CONTEXT.
@@ -47,13 +52,17 @@ test_esys_ecc_parameters(ESYS_CONTEXT * esys_context)
     }
     goto_if_error(r, "Error: ECC_Parameters", error);
 
+    SAFE_FREE(parameters);
+
     return EXIT_SUCCESS;
 
  error:
+    SAFE_FREE(parameters);
+
     return failure_return;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_ecc_parameters(esys_context);
 }
